@@ -6,9 +6,9 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+use crate::dbs;
 use crate::messaging::{client::Error as ErrorMessage, MessageId, MessageType};
 use crate::routing::Prefix;
-use crate::transfers::Error as TransferError;
 use crate::types::{DataAddress, Error as DtError, PublicKey};
 use std::io;
 use thiserror::Error;
@@ -31,9 +31,9 @@ pub enum Error {
     /// Not enough in the section to perform Chunk operation
     #[error("Not enough Adults available in Section({0:?}) to perform operation")]
     NoAdults(Prefix),
-    /// Not enough space in `DataStore` to perform `put`.
-    #[error("Not enough space")]
-    NotEnoughSpace,
+    /// Database error.
+    #[error("Database error:: {0}")]
+    Database(#[from] dbs::Error),
     /// Not enough storage available on the network.
     #[error("Not enough storage available on the network")]
     NetworkFull,
@@ -97,18 +97,18 @@ pub enum Error {
     /// Node not found for rewarding
     #[error("Node not found for rewards")]
     NodeNotFoundForReward,
-    /// Key, Value pair not found in `DataStore`.
-    #[error("No such chunk: {0:?}")]
-    NoSuchChunk(DataAddress),
+    /// Key, Value pair not found.
+    #[error("No such data: {0:?}")]
+    NoSuchData(DataAddress),
     /// Unable to process fund churn message.
     #[error("Cannot process fund churn message")]
     NotChurningFunds,
     /// Creating temp directory failed.
     #[error("Could not create temp store: {0}")]
     TempDirCreationFailed(String),
-    /// Chunk Store Id could not be found
-    #[error("Could not fetch StoreId")]
-    NoStoreId,
+    // /// Chunk Store Id could not be found
+    // #[error("Could not fetch StoreId")]
+    // NoStoreId,
     /// Threshold crypto combine signatures error
     #[error("Could not combine signatures")]
     CouldNotCombineSignatures,
@@ -133,27 +133,12 @@ pub enum Error {
     /// Network message error.
     #[error("Network message error:: {0}")]
     Message(#[from] crate::messaging::Error),
-    /// PickleDb error.
-    #[error("PickleDb error:: {0}")]
-    PickleDb(#[from] pickledb::error::Error),
     /// NetworkData error.
     #[error("Network data error:: {0}")]
     NetworkData(#[from] crate::types::Error),
-    /// transfers error.
-    #[error("Transfer data error:: {0}")]
-    Transfer(#[from] crate::transfers::Error),
     /// Routing error.
     #[error("Routing error:: {0}")]
     Routing(#[from] crate::routing::Error),
-    /// Transfer has already been registered
-    #[error("Transfer has already been registered")]
-    TransferAlreadyRegistered,
-    /// Transfer message is invalid.
-    #[error("Signed transfer for Dot: '{0:?}' is not valid. Debit or credit are missing")]
-    InvalidSignedTransfer(crdts::Dot<PublicKey>),
-    /// Transfer message is invalid.
-    #[error("Propagated Credit Agreement proof is not valid. Proof received: {0:?}")]
-    InvalidPropagatedTransfer(crate::types::CreditAgreementProof),
     /// Message is invalid.
     #[error("Message with id: '{0:?}' is invalid. {1}")]
     InvalidMessage(MessageId, String),
@@ -185,13 +170,7 @@ pub(crate) fn convert_to_error_message(error: Error) -> ErrorMessage {
         Error::InvalidOperation(msg) => ErrorMessage::InvalidOperation(msg),
         Error::InvalidMessage(_, msg) => ErrorMessage::InvalidOperation(msg),
         Error::InvalidOwner(key) => ErrorMessage::InvalidOwners(key),
-        Error::InvalidSignedTransfer(_) => ErrorMessage::InvalidSignature,
-        Error::TransferAlreadyRegistered => ErrorMessage::TransactionIdExists,
-        Error::Transfer(TransferError::OperationOutOfOrder(received, expected)) => {
-            ErrorMessage::MissingTransferHistory(received, expected)
-        }
-        Error::NoSuchChunk(address) => ErrorMessage::DataNotFound(address),
-        Error::NotEnoughSpace => ErrorMessage::NotEnoughSpace,
+        Error::NoSuchData(address) => ErrorMessage::DataNotFound(address),
         Error::TempDirCreationFailed(_) => ErrorMessage::FailedToWriteFile,
         Error::DataExists => ErrorMessage::DataExists,
         Error::NetworkData(error) => convert_dt_error_to_error_message(error),
