@@ -6,16 +6,15 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::messaging::{Itinerary, MessageId, MessageType};
-use crate::node::{state_db::store_network_keypair, utils, Config as NodeConfig, Error, Result};
+use crate::messaging::{Itinerary, MessageType};
+use crate::node::{state_db::store_network_keypair, Config as NodeConfig, Error, Result};
 use crate::routing::{
     Config as RoutingConfig, Error as RoutingError, EventStream, PeerUtils, Routing as RoutingNode,
     SectionAuthorityProviderUtils,
 };
-use crate::types::{PublicKey, Signature, SignatureShare};
+use crate::types::{utils, PublicKey, Signature, SignatureShare};
 use bls::PublicKeySet;
 use ed25519_dalek::PublicKey as Ed25519PublicKey;
-use rand::{seq::SliceRandom, SeedableRng};
 use secured_linked_list::SecuredLinkedList;
 use serde::Serialize;
 use std::{
@@ -66,6 +65,7 @@ impl Network {
     }
 
     /// Sign with our BLS PK Share
+    #[allow(unused)]
     pub async fn sign_as_elder<T: Serialize>(&self, data: &T) -> Result<SignatureShare> {
         let bls_pk = self
             .routing
@@ -146,24 +146,6 @@ impl Network {
             .map_err(From::from)
     }
 
-    pub async fn get_closest_elders_to(
-        &self,
-        name: &XorName,
-        msg_id: MessageId,
-        count: usize,
-    ) -> Result<BTreeSet<XorName>> {
-        self.routing
-            .matching_section(name)
-            .await
-            .map(|auth_provider| {
-                let mut targets: Vec<_> = auth_provider.names().iter().cloned().collect();
-                let mut rng = rand_chacha::ChaChaRng::from_seed(*msg_id.as_ref());
-                targets.shuffle(&mut rng);
-                targets.into_iter().take(count).collect()
-            })
-            .map_err(From::from)
-    }
-
     pub async fn our_public_key_set(&self) -> Result<PublicKeySet> {
         self.routing.public_key_set().await.map_err(Error::Routing)
     }
@@ -223,6 +205,7 @@ impl Network {
     }
 
     /// get our PKshare
+    #[allow(unused)]
     pub async fn our_public_key_share(&self) -> Result<PublicKey> {
         let index = self.our_index().await?;
         Ok(PublicKey::from(
@@ -231,6 +214,7 @@ impl Network {
     }
 
     /// BLS key index in routing for key shares
+    #[allow(unused)]
     pub async fn our_index(&self) -> Result<usize> {
         self.routing.our_index().await.map_err(Error::Routing)
     }
@@ -282,6 +266,7 @@ impl Network {
             .collect::<Vec<_>>()
     }
 
+    #[allow(unused)]
     pub async fn our_members(&self) -> BTreeMap<XorName, u8> {
         let elders: Vec<_> = self
             .routing
